Module blaxel.models.template_variable
======================================

Classes
-------

`TemplateVariable(description: blaxel.types.Unset | str = <blaxel.types.Unset object>, name: blaxel.types.Unset | str = <blaxel.types.Unset object>, path: blaxel.types.Unset | str = <blaxel.types.Unset object>, secret: blaxel.types.Unset | bool = <blaxel.types.Unset object>)`
:   Blaxel template variable
    
    Attributes:
        description (Union[Unset, str]): Description of the variable
        name (Union[Unset, str]): Name of the variable
        path (Union[Unset, str]): Path of the variable
        secret (Union[Unset, bool]): Whether the variable is secret
    
    Method generated by attrs for class TemplateVariable.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `description: blaxel.types.Unset | str`
    :

    `name: blaxel.types.Unset | str`
    :

    `path: blaxel.types.Unset | str`
    :

    `secret: blaxel.types.Unset | bool`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :